#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytes
version:              0.17.5
visibility:           public
id:                   bytes-0.17.5-GxfbxpVFjCKCyNDP4hQrim
key:                  bytes-0.17.5-GxfbxpVFjCKCyNDP4hQrim
license:              BSD-3-Clause
copyright:            Copyright (C) 2013-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             https://github.com/ekmett/bytes
synopsis:             Sharing code for serialization between binary and cereal
description:          Sharing code for serialization between binary and cereal.
category:             Data, Serialization
abi:                  8ee5dc0a23619eb38d7d343ad2b2cdee
exposed:              True
exposed-modules:
    Data.Bytes.Get Data.Bytes.Put Data.Bytes.Serial Data.Bytes.Signed
    Data.Bytes.VarInt

import-dirs:          /usr/lib/ghc-9.6.6/site-local/bytes-0.17.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bytes-0.17.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bytes-0.17.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytes
hs-libraries:         HSbytes-0.17.5-GxfbxpVFjCKCyNDP4hQrim
depends:
    base-4.18.2.1 binary-0.8.9.1
    binary-orphans-1.0.5.1-7R0FqcffyqEBZRVqWiJcjZ bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    hashable-1.4.7.0-GIhdlNoQDSBAO6SjAK3pjT
    scientific-0.3.8.1-3ttkxdCo3DY31RbKExXamW text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd

haddock-interfaces:   /usr/share/doc/haskell-bytes/html/bytes.haddock
haddock-html:         /usr/share/doc/haskell-bytes/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

